%define major 2
%define minor 35
%define fix 1

%define _sbindir %{_bindir}

# ensure libutil.so.2 with symbols for err, warn, flock is installed
%define required_libutil_version 0.10.0

Name: util-linux
Version: %{major}.%{minor}.%{fix}
Release: 3
# see https://github.com/karelzak/util-linux/blob/master/README.licensing
License: GPL-3.0-or-later and GPL-2.0-or-later and GPL-2.0 and LGPL-2.1-or-later and BSD-3-Clause and BSD-4-Clause-UC
Summary: A collection of basic system utilities
Url: https://github.com/karelzak/util-linux

Source0: https://www.kernel.org/pub/linux/utils/%{name}/v%{major}.%{minor}/%{name}-%{version}.tar.gz

Patch1: util-linux-syscall.patch
Patch2: util-linux-cloexec.patch
Patch3: util-linux-timeradd.patch
Patch4: util-linux-setsid.patch
Patch5: util-linux-termios.patch
Patch6: util-linux-no-faccessat.patch

BuildRequires: autoconf
BuildRequires: automake
BuildRequires: libtool
BuildRequires: pkg-config
BuildRequires: gettext-tools
# err/warn implmentation is in libutil >= 0.10.0
BuildRequires: libutil-devel >= %{required_libutil_version}
BuildRequires: bison

Requires: libutil2 >= %{required_libutil_version}

%description
The util-linux package contains a large variety of low-level system
utilities that are necessary for a Linux system to function.

%package -n libuuid-devel

Requires: libuuid1 == %{version}-%{release}
Summary: UUID library development files.
License: BSD-3-Clause

%description -n libuuid-devel
UUID library development files.

%package -n libuuid1
Summary:  A library for generating UUIDs
Requires: libutil2 >= %{required_libutil_version}

%description -n libuuid1
A library for generating UUIDs.

%package -n libsmartcols1
Summary: Formatting library for ls-like programs
Requires: libutil2 >= %{required_libutil_version}
License: GPL-3.0-or-later

%description -n libsmartcols1
This is a library for ls-like terminal programs, part of util-linux.

%package -n libsmartcols-devel
Summary: Formatting library for ls-like programs
Requires: libsmartcols1 = %{version}-%{release}
License: GPL-3.0-or-later

%description -n libsmartcols-devel
Development library and headers for libsmartcols, part of util-linux.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1

%build

./autogen.sh

%configure \
  ac_cv_func_openat=no \
  ac_cv_func_fstatat=no \
  ac_cv_func_unlinkat=no \
  ac_cv_func_setitimer=no \
  ac_cv_lib_rt_clock_gettime=no \
  ac_cv_func_timer_create=no \
  ac_cv_lib_rt_timer_create=no \
  ac_cv_search_timer_create=no \
  LDFLAGS="-lutil -Wl,-brtl -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib" \
  --with-aix-soname=svr4 \
  --without-btrfs \
  --without-systemd \
  --enable-shared=yes \
  --enable-static=no \
  --enable-libuuid \
  --disable-libblkid \
  --disable-libfdisk \
  --disable-libmount \
  --disable-libfdisk \
  --disable-bfs \
  --disable-cramfs \
  --disable-fdisks \
  --disable-hwclock \
  --disable-ipcs \
  --disable-ipcrm \
  --disable-logger \
  --disable-minix \
  --disable-pylibmount \
  --disable-schedutils \
  --disable-wall \
  --disable-wipefs \
  --disable-bash-completion \
  # end

# libtool will automatically add "convenience libraries" to the
# list of objects to generate the exports file from. This might
# make sense if you were using a static library to generate the
# shared library from, but here util-linux uses libcommon.a to
# static link internal functions which we do not want to export
sed -i 's|\(^export_symbols_cmds=.*\) [\]$convenience\(.*\)|\1\2|' libtool

%make_build

%check
make check

%install
%make_install

# These won't work in PASE
rm %{buildroot}%{_bindir}/mkfs
rm %{buildroot}%{_mandir}/man8/mkfs.8
rm %{buildroot}%{_bindir}/mkswap
rm %{buildroot}%{_mandir}/man8/mkswap.8

# We don't have script or scriptlive to generate
# the files used by scriptreplace, so it doesn't
# seem too beneficial to ship
rm %{buildroot}%{_bindir}/scriptreplay
rm %{buildroot}%{_mandir}/man1/scriptreplay.1

# We dont have tcsh and shebang line depenency generator
# will cause installation problems if we ship this
rm %{buildroot}%{_docdir}/util-linux/getopt/getopt-parse.tcsh

%files
%defattr(-, qsys, *none)
%{_bindir}/cal
%{_bindir}/col
%{_bindir}/colcrt
%{_bindir}/colrm
%{_bindir}/column
%{_bindir}/getopt
%{_bindir}/hardlink
%{_bindir}/hexdump
%{_bindir}/ipcmk
%{_bindir}/isosize
%{_bindir}/look
%{_bindir}/mcookie
%{_bindir}/mesg
%{_bindir}/namei
%{_bindir}/nologin
%{_bindir}/rename
%{_bindir}/renice
%{_bindir}/rev
%{_bindir}/setsid
%{_bindir}/uuidgen
%{_bindir}/uuidparse
%{_bindir}/whereis

%{_docdir}/util-linux/getopt/getopt-parse.bash
%{_mandir}/man1/cal.1.*
%{_mandir}/man1/col.1.*
%{_mandir}/man1/colcrt.1.*
%{_mandir}/man1/colrm.1.*
%{_mandir}/man1/column.1.*
%{_mandir}/man1/getopt.1.*
%{_mandir}/man1/hardlink.1.*
%{_mandir}/man1/hexdump.1.*
%{_mandir}/man1/ipcmk.1.*
%{_mandir}/man1/look.1.*
%{_mandir}/man1/mcookie.1.*
%{_mandir}/man1/mesg.1.*
%{_mandir}/man1/namei.1.*
%{_mandir}/man1/rename.1.*
%{_mandir}/man1/renice.1.*
%{_mandir}/man1/rev.1.*
%{_mandir}/man1/setsid.1.*
%{_mandir}/man1/uuidgen.1.*
%{_mandir}/man1/uuidparse.1.*
%{_mandir}/man1/whereis.1.*
%{_mandir}/man5/terminal-colors.d.5.*
%{_mandir}/man8/isosize.8.*
%{_mandir}/man8/nologin.8.*


%files -n libsmartcols-devel
%defattr(-, qsys, *none)
%{_includedir}/libsmartcols/libsmartcols.h
%{_libdir}/libsmartcols.so
%{_libdir}/pkgconfig/smartcols.pc


%files -n libsmartcols1
%defattr(-, qsys, *none)
%{_libdir}/libsmartcols.so.1


%files -n libuuid-devel
%defattr(-, qsys, *none)
%license Documentation/licenses/COPYING.BSD-3-Clause
%{_includedir}/uuid/uuid.h
%{_libdir}/libuuid.so
%{_libdir}/pkgconfig/uuid.pc
%{_mandir}/man3/uuid.3*
%{_mandir}/man3/uuid_clear.3*
%{_mandir}/man3/uuid_compare.3*
%{_mandir}/man3/uuid_copy.3*
%{_mandir}/man3/uuid_generate.3*
%{_mandir}/man3/uuid_generate_random.3*
%{_mandir}/man3/uuid_generate_time.3*
%{_mandir}/man3/uuid_generate_time_safe.3*
%{_mandir}/man3/uuid_is_null.3*
%{_mandir}/man3/uuid_parse.3*
%{_mandir}/man3/uuid_time.3*
%{_mandir}/man3/uuid_unparse.3*

%files -n libuuid1
%defattr(-, qsys, *none)
%{_libdir}/libuuid.so.1

%changelog
* Tue Mar 9 2021 - Abdirahim Musse <abdirahim.musse@ibm.com> - 2.35.1
- Add requirement for libutil2 >= 0.10.0
- To ensure libutil.so.2 built with symbols for err, warn, and flock is installed

* Mon Feb 22 2021 Kevin Adler <kadler@us.ibm.com> - 2.35.1
- Build and ship useful utilities
- Build and ship libsmartcols needed by various utils

* Wed May 27 2020 Kevin Adler <kadler@us.ibm.com> - 2.35.1
- Use generic paths for man and info pages to allow for compression

* Tue Apr 28 2020 - Abdirahim Musse <abdirahim.musse@ibm.com> - 2.35.1
- Update to 2.35.1

* Wed Jan 29 2020 - Abdirahim Musse <abdirahim.musse@ibm.com>
- Initial spec
